from setuptools import setup
from os import path, chdir, getcwd, walk, remove
from glob import glob
from platform import machine, system

chdir(path.abspath(path.dirname(__file__)))


def read(filename):
    try:
        with open(filename, 'rb') as fp:
            data = fp.read().decode('utf-8')
    except UnicodeDecodeError:
        with open(filename, 'r') as fp:
            data = fp.read()
    return data


def find_version(file_paths):
    version_file = read(file_paths)
    import re
    version_match = re.search(
        r"^__version__ = ['\"]([^'\"]*)['\"]",
        version_file,
        re.M,
    )
    if version_match:
        return version_match.group(1)

    raise RuntimeError("Unable to find version string.")


def get_package_data_list():

    machine_name = machine().lower()
    if system().lower() == "linux":

        if machine().lower() == "x86_64":
            ends_with = "linux-gnu.so"

        elif machine().lower().startswith("arm"):
            machine_name = "armv6l"
            ends_with = "arm-linux-gnueabihf.so"

    elif system().lower() == "windows":

        if machine().lower() == "amd64":
            ends_with = "win_amd64.pyd"

    elif system().lower() == "darwin":

        if machine().lower() == "amd64":
            ends_with = "darwin.so"

        elif machine().lower() == "arm64":
            ends_with = "darwin.so"
    else:
        raise RuntimeError("Unable to support",
                           machine().lower() + "-" + system().lower())

    _find_all_files = ['__init__.py', '__main__.py']
    from os import walk, path
    from shutil import copyfile
    for root, subfiles, files in walk(path.join('src', 'ext', machine_name + "-" + system().lower())):
        for file in files:
            copyfile(path.join(root, file), path.join('src', file))
            _find_all_files.append(file)

    return _find_all_files


setup(
    name="sourcedefender",
    version=find_version('src/__init__.py'),
    python_requires="!=2.*,>=3.6",
    description='Advanced encryption protecting your python codebase.',
    long_description=read(path.join(getcwd(), 'README.md')) + '\n',
    long_description_content_type="text/markdown",
    author='SOURCEdefender',
    author_email="hello@sourcedefender.co.uk",
    keywords="encryption source aes",
    packages=['sourcedefender'],
    package_dir={'sourcedefender': 'src'},
    package_data={'sourcedefender': get_package_data_list()},
    install_requires=open("requirements.txt").read().splitlines(),
    url="https://sourcedefender.co.uk/",
    project_urls={
        'Dashboard': 'https://dashboard.sourcedefender.co.uk/',
    },
    license='Other/Proprietary License',
    entry_points={
        'console_scripts': [
            'sourcedefender = sourcedefender.encrypt:main',
        ]
    },
    zip_safe=True,
    # https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Other Audience',
        'Intended Audience :: Science/Research',
        'Intended Audience :: System Administrators',

        'Topic :: Security',
        'Topic :: Security :: Cryptography',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Software Distribution',
        'Topic :: Utilities',

        'License :: Other/Proprietary License',

        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX :: Linux',

        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: CPython'
    ],
)

for file in get_package_data_list():
    if not file.endswith(".py"):
        remove(path.join('src', file))
